var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import SvgTags from "./svg-tags";
/**
 * Base for circle type implementations
 */
var BaseCircle = /** @class */ (function () {
    function BaseCircle() {
        /**
         * @description Array of all tags that needs to be appended to the dom
         */
        this.tags = [];
    }
    /**
     * @description Fires scroll event if animateInView is set to true and runs checkAnimation
     */
    BaseCircle.prototype.animateInView = function () {
        var _this = this;
        if (this.options.animateInView) {
            window.addEventListener("scroll", function () {
                _this.checkAnimation(_this.options.id);
            });
        }
    };
    /**
     * @description When circle is in view port it animates the foreground circle
     */
    BaseCircle.prototype.checkAnimation = function (svgParentId) {
        var _this = this;
        var circleContainer = document.getElementById(svgParentId);
        var foregroundCircle = document.getElementById("arc-" + svgParentId);
        var inView = this.isElementInViewport(circleContainer);
        if (!circleContainer.classList.contains("reanimated") && inView) {
            circleContainer.classList.add("reanimated");
            setTimeout(function () { return _this.animate(foregroundCircle); }, 250);
        }
    };
    /**
     * @description Calculates if the circle is in viewport
     * @param circleContainer
     */
    BaseCircle.prototype.isElementInViewport = function (circleContainer) {
        var offsetTop = circleContainer.offsetTop;
        var scrollPositionTop = window.scrollY;
        var windowHeight = window.innerHeight;
        return scrollPositionTop < offsetTop && scrollPositionTop + windowHeight > offsetTop;
    };
    /**
     * @description Draws the svg tag
     * @param additionalAttributes
     */
    BaseCircle.prototype.drawContainer = function (additionalAttributes) {
        var _a = this.getViewBoxParams(), minX = _a.minX, minY = _a.minY, width = _a.width, height = _a.height;
        var container = SvgTags.addSvg(__assign({ width: "100%", height: "100%", viewBox: minX + " " + minY + " " + width + " " + height, id: "svg-" + this.options.id, preserveAspectRatio: "xMinYMin meet" }, additionalAttributes));
        this.tags.push({
            element: container,
            parentId: this.options.id,
        });
    };
    /**
     * @description Get viewBox parameters, resize the view if the border would overflow
     */
    BaseCircle.prototype.getViewBoxParams = function () {
        var _a = this.options, foregroundCircleWidth = _a.foregroundCircleWidth, backgroundCircleWidth = _a.backgroundCircleWidth;
        var circleWidth = backgroundCircleWidth;
        // Get thicker circle stroke width, foreground or background
        if (foregroundCircleWidth > backgroundCircleWidth) {
            circleWidth = foregroundCircleWidth;
        }
        var minX = 0;
        var minY = 0;
        var width = this.size.width;
        var height = this.size.height;
        if (foregroundCircleWidth > 5 || backgroundCircleWidth > 5) {
            width = this.size.width + (1.5 * circleWidth);
            height = this.size.height + (1.5 * circleWidth);
        }
        return { minX: minX, minY: minY, width: width, height: height };
    };
    /**
     * @description Appends the tags to the dom
     */
    BaseCircle.prototype.append = function () {
        this.tags.forEach(function (tag) {
            var parent = document.getElementById(tag.parentId);
            parent.appendChild(tag.element);
        });
    };
    /**
     * @description Initialize basic values for circle
     * @param options
     * @param size
     */
    BaseCircle.prototype.initialize = function (options, size) {
        this.options = options;
        this.size = size;
    };
    return BaseCircle;
}());
export { BaseCircle };
