var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var Options = /** @class */ (function () {
    function Options() {
        /**
         * @description Default options if option is not set on initialisation
         */
        this.defaultOptions = {
            point: false,
            pointSize: 60,
            percent: 75,
            foregroundCircleWidth: 5,
            backgroundCircleWidth: 15,
            animation: true,
            animationStep: 1,
            noPercentageSign: false,
            animateInView: false,
            strokeLinecap: "butt",
            type: "SimpleCircle",
            textReplacesPercentage: false,
        };
    }
    /**
     * @description Get data attributes from tag
     * @param options
     */
    Options.getDataAttributes = function (options) {
        var circleContainer = document.getElementById(options.id);
        var dataOptions = { percent: options.percent };
        for (var key in circleContainer.dataset) {
            if (circleContainer.dataset.hasOwnProperty(key)) {
                var value = circleContainer.dataset[key];
                if (value === "false" || value === "true") {
                    dataOptions[key] = value === "true";
                }
                else if (Number(value)) {
                    dataOptions[key] = Number(value);
                }
                else {
                    dataOptions[key] = value;
                }
            }
        }
        return dataOptions;
    };
    /**
     * @description Merge default options and custom option on initialisation
     * @param options
     * @param checkDataAttributes
     * @returns Options['defaultOptions']
     */
    Options.prototype.mergeOptions = function (options, checkDataAttributes) {
        if (checkDataAttributes === void 0) { checkDataAttributes = false; }
        var mergedOptions = __assign(__assign({}, this.defaultOptions), options);
        if (checkDataAttributes) {
            var dataOptions = Options.getDataAttributes(options);
            mergedOptions = __assign(__assign({}, mergedOptions), dataOptions);
        }
        return mergedOptions;
    };
    return Options;
}());
export default Options;
