import ObjectHelper from "../helper/object-helper";
import SvgTagsHelper from "../helper/svg-tags-helper";
var SvgTags = /** @class */ (function () {
    function SvgTags() {
    }
    /**
     * @description Adds a svg tag with attributes
     * @param attributes
     * @returns SVGElement
     */
    SvgTags.addSvg = function (attributes) {
        var svg = document.createElementNS(SvgTags.namespaceURI, "svg");
        attributes.class = "circle-container " + ObjectHelper.extractPropertyFromObject(attributes, "class");
        SvgTagsHelper.setAttributes(svg, attributes);
        return svg;
    };
    /**
     * @description Adds a circle tag with attributes
     * @param attributes
     * @returns SVGCircleElement
     */
    SvgTags.addCircle = function (attributes) {
        var circle = document.createElementNS(SvgTags.namespaceURI, "circle");
        SvgTagsHelper.setAttributes(circle, attributes);
        return circle;
    };
    /**
     * @description Adds a path tag with attributes
     * @param attributes
     * @returns SVGPathElement
     */
    SvgTags.addArc = function (attributes) {
        var arc = document.createElementNS(SvgTags.namespaceURI, "path");
        SvgTagsHelper.setAttributes(arc, attributes);
        return arc;
    };
    /**
     * @description Adds a text tag with attributes
     * @param attributes
     * @returns SVGTextElement
     */
    SvgTags.addText = function (attributes) {
        var text = document.createElementNS(SvgTags.namespaceURI, "text");
        text.setAttributeNS(null, "text-anchor", "middle");
        SvgTagsHelper.setAttributes(text, attributes);
        return text;
    };
    /**
     * @description Adds defs tag to svg to draw a gradient
     * @param attributes
     */
    SvgTags.addDefs = function (attributes) {
        var defs = document.createElementNS(SvgTags.namespaceURI, "defs");
        var linearGradient = document.createElementNS(SvgTags.namespaceURI, "linearGradient");
        var linearGradientAttributes = {
            id: "linearGradient",
        };
        SvgTagsHelper.setAttributes(linearGradient, linearGradientAttributes);
        var firstStop = document.createElementNS(SvgTags.namespaceURI, "stop");
        var firstStopAttributes = {
            "offset": "0",
            "stop-color": attributes.gradientStart,
        };
        SvgTagsHelper.setAttributes(firstStop, firstStopAttributes);
        var secondStop = document.createElementNS(SvgTags.namespaceURI, "stop");
        var secondStopAttributes = {
            "offset": "1",
            "stop-color": attributes.gradientEnd,
        };
        SvgTagsHelper.setAttributes(secondStop, secondStopAttributes);
        linearGradient.appendChild(firstStop);
        linearGradient.appendChild(secondStop);
        defs.appendChild(linearGradient);
        return defs;
    };
    SvgTags.namespaceURI = "http://www.w3.org/2000/svg";
    return SvgTags;
}());
export default SvgTags;
