var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import SvgTags from "../base-class/svg-tags";
import ObjectHelper from "../helper/object-helper";
import { StyleHelper } from "../helper/style-helper";
import SvgTagsHelper from "../helper/svg-tags-helper";
import SimpleCircle from "./simple-circle";
/**
 * Every circle gets dynamically called by the given type in the options object example: { type: 'HalfCircle' }
 */
var HalfCircle = /** @class */ (function (_super) {
    __extends(HalfCircle, _super);
    function HalfCircle() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @inheritDoc
     */
    HalfCircle.prototype.drawCircle = function () {
        var additionalContainerAttributes = {
            class: ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "svgContainer"),
        };
        this.drawContainer(additionalContainerAttributes);
        this.drawBackgroundCircle();
        this.drawForegroundCircle();
        this.drawText();
        this.append();
    };
    /**
     * @description Draws the background circle
     */
    HalfCircle.prototype.drawBackgroundCircle = function () {
        var startAngle = 270;
        var endAngle = 90;
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "backgroundCircle");
        var arc = SvgTags.addArc({
            "id": "bg-arc-" + this.options.id,
            "d": SvgTagsHelper.describeArc(this.coordinates.x, this.coordinates.y, this.radius, startAngle, endAngle),
            "class": "background-circle " + customCssClass,
            "stroke-width": this.options.backgroundCircleWidth,
        });
        this.tags.push({
            element: arc,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Draws the foreground circle by given percentage with optional animation
     */
    HalfCircle.prototype.drawForegroundCircle = function () {
        var endAngle = 180 / 100 * this.options.percent;
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "foregroundCircle");
        var arc = SvgTags.addArc({
            "id": "arc-" + this.options.id,
            "class": "foreground-circle " + customCssClass,
            "d": SvgTagsHelper.describeArc(this.coordinates.x, this.coordinates.y, this.radius, 0, endAngle),
            "transform": "rotate(-90, " + this.coordinates.x + ", " + this.coordinates.y + ")",
            "stroke-width": this.options.foregroundCircleWidth,
            "stroke-linecap": this.options.strokeLinecap,
        });
        if (this.options.animation) {
            this.animate(arc);
        }
        this.tags.push({
            element: arc,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Animates circle counter clock wise
     * @param arc
     */
    HalfCircle.prototype.animate = function (arc) {
        StyleHelper.animateArc({
            arc: arc,
            arcParams: {
                percent: this.options.percent,
                x: this.coordinates.x,
                y: this.coordinates.y,
                radius: this.radius,
                endAngleGrade: 180,
            },
            animationStep: this.options.animationStep,
            progressColors: this.options.progressColors,
        }, this.options.onAnimationEnd);
    };
    return HalfCircle;
}(SimpleCircle));
export default HalfCircle;
