var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { BaseCircle } from "../base-class/base-circle";
import SvgTags from "../base-class/svg-tags";
import ObjectHelper from "../helper/object-helper";
import { StyleHelper } from "../helper/style-helper";
import SvgTagsHelper from "../helper/svg-tags-helper";
/**
 * Every circle gets dynamically called by the given type in the options object example: { type: 'PlainCircle' }
 */
var PlainCircle = /** @class */ (function (_super) {
    __extends(PlainCircle, _super);
    function PlainCircle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.coordinates = {
            x: 0,
            y: 0,
        };
        _this.additionalCssClasses = {};
        return _this;
    }
    /**
     * @inheritDoc
     */
    PlainCircle.prototype.initialize = function (options, size) {
        _super.prototype.initialize.call(this, options, size);
        var maxSize = this.size.maxSize;
        this.coordinates = {
            x: maxSize / 2,
            y: maxSize / 2,
        };
        this.radius = maxSize / 2.2;
        if (this.options.additionalCssClasses) {
            this.additionalCssClasses = this.options.additionalCssClasses;
        }
        this.animateInView();
    };
    /**
     * @inheritDoc
     */
    PlainCircle.prototype.drawCircle = function () {
        this.drawContainer();
        this.drawPlainCircle();
        this.append();
    };
    /**
     * @description Draws the circle by given percentage with optional animation
     */
    PlainCircle.prototype.drawPlainCircle = function () {
        var endAngle = 360 / 100 * this.options.percent;
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "foregroundCircle");
        var arc = SvgTags.addArc({
            "id": "arc-" + this.options.id,
            "class": "foreground-circle " + customCssClass,
            "d": SvgTagsHelper.describeArc(this.coordinates.x, this.coordinates.y, this.radius, 0, endAngle),
            "stroke-width": this.options.foregroundCircleWidth,
            "stroke-linecap": this.options.strokeLinecap,
        });
        if (this.options.animation) {
            this.animate(arc);
        }
        this.tags.push({
            element: arc,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Animates circle counter clock wise
     * @param arc
     */
    PlainCircle.prototype.animate = function (arc) {
        StyleHelper.animateArc({
            arc: arc,
            arcParams: {
                percent: this.options.percent,
                x: this.coordinates.x,
                y: this.coordinates.y,
                radius: this.radius,
            },
            animationStep: this.options.animationStep,
            progressColors: this.options.progressColors,
        }, this.options.onAnimationEnd);
    };
    return PlainCircle;
}(BaseCircle));
export default PlainCircle;
