var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { BaseCircle } from "../base-class/base-circle";
import SvgTags from "../base-class/svg-tags";
import ObjectHelper from "../helper/object-helper";
import { StyleHelper } from "../helper/style-helper";
import SvgTagsHelper from "../helper/svg-tags-helper";
/**
 * Every circle gets dynamically called by the given type in the options object
 * example: { type: 'SimpleCircle' }
 */
var SimpleCircle = /** @class */ (function (_super) {
    __extends(SimpleCircle, _super);
    function SimpleCircle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.coordinates = {
            x: 0,
            y: 0,
        };
        _this.additionalCssClasses = {};
        return _this;
    }
    /**
     * @inheritDoc
     */
    SimpleCircle.prototype.initialize = function (options, size) {
        _super.prototype.initialize.call(this, options, size);
        var maxSize = this.size.maxSize;
        this.coordinates = {
            x: maxSize / 2,
            y: maxSize / 2,
        };
        this.radius = maxSize / 2.2;
        if (this.options.additionalCssClasses) {
            this.additionalCssClasses = this.options.additionalCssClasses;
        }
        this.animateInView();
    };
    /**
     * @inheritDoc
     */
    SimpleCircle.prototype.drawCircle = function () {
        var additionalContainerAttributes = {
            class: ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "svgContainer"),
        };
        this.drawContainer(additionalContainerAttributes);
        if (this.options.strokeGradient) {
            this.drawLinearGradient();
        }
        this.drawBackgroundCircle();
        this.drawForegroundCircle();
        if (this.options.point) {
            this.drawPoint();
        }
        if (this.options.icon) {
            this.drawIcon();
        }
        this.drawText();
        if (!this.options.textReplacesPercentage && this.options.text) {
            this.drawInfoText();
        }
        this.append();
    };
    /**
     * @description Draws background circle
     */
    SimpleCircle.prototype.drawBackgroundCircle = function () {
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "backgroundCircle");
        var circle = SvgTags.addCircle({
            "id": "circle-" + this.options.id,
            "class": "background-circle " + customCssClass,
            "cx": String(this.coordinates.x),
            "cy": String(this.coordinates.y),
            "r": String(this.radius),
            "stroke-width": this.options.backgroundCircleWidth,
        });
        this.tags.push({
            element: circle,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Draws a point into the circle, behind the text
     */
    SimpleCircle.prototype.drawPoint = function () {
        var pointSize = this.radius / 100 * this.options.pointSize;
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "point");
        var circle = SvgTags.addCircle({
            id: "point-" + this.options.id,
            class: "point-circle " + customCssClass,
            cx: String(this.coordinates.x),
            cy: String(this.coordinates.y),
            r: String(pointSize),
        });
        this.tags.push({
            element: circle,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Draws foreground circle
     */
    SimpleCircle.prototype.drawForegroundCircle = function () {
        var endAngle = 360 / 100 * this.options.percent;
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "foregroundCircle");
        var attributes = {
            "id": "arc-" + this.options.id,
            "class": "foreground-circle " + customCssClass,
            "d": SvgTagsHelper.describeArc(this.coordinates.x, this.coordinates.y, this.radius, 0, endAngle),
            "stroke-width": this.options.foregroundCircleWidth,
            "stroke-linecap": this.options.strokeLinecap,
        };
        if (this.options.strokeGradient) {
            attributes.stroke = "url(#linearGradient)";
            attributes.class = "foreground-circle-without-stroke-color " + customCssClass;
        }
        var arc = SvgTags.addArc(attributes);
        if (this.options.animation) {
            this.animate(arc);
        }
        this.tags.push({
            element: arc,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Animates circle counter clock wise
     * @param arc
     * @param updatedPercent
     */
    SimpleCircle.prototype.animate = function (arc, updatedPercent) {
        StyleHelper.animateArc({
            arc: arc,
            arcParams: {
                percent: updatedPercent ? updatedPercent : this.options.percent,
                x: this.coordinates.x,
                y: this.coordinates.y,
                radius: this.radius,
            },
            animationStep: this.options.animationStep,
            progressColors: this.options.progressColors,
        }, this.options.onAnimationEnd);
    };
    /**
     * @description Draws font awesome icon
     */
    SimpleCircle.prototype.drawIcon = function () {
        var icon = this.options.icon;
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "icon");
        var text = SvgTags.addText({
            id: "text-" + this.options.id,
            x: String(this.coordinates.x),
            y: String(this.coordinates.y - 25),
            class: "circle-icon fa " + customCssClass,
        });
        text.innerHTML = "&#x" + icon + ";";
        this.tags.push({
            element: text,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Draws percentage
     */
    SimpleCircle.prototype.drawText = function () {
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "text");
        var text = SvgTags.addText({
            id: "text-" + this.options.id,
            x: String(this.coordinates.x),
            y: String(this.coordinates.y),
            class: "circle-text " + customCssClass,
        });
        var percentageSign = this.options.noPercentageSign ? "" : "%";
        var content = "" + this.options.percent + percentageSign;
        if (this.options.textReplacesPercentage && this.options.text) {
            content = this.options.text;
        }
        text.textContent = content;
        this.tags.push({
            element: text,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Draws info text below percentage
     */
    SimpleCircle.prototype.drawInfoText = function () {
        var customCssClass = ObjectHelper.extractPropertyFromObject(this.additionalCssClasses, "infoText");
        var text = SvgTags.addText({
            id: "text-" + this.options.id,
            x: String(this.coordinates.x),
            y: String(this.coordinates.y + 20),
            class: "circle-info-text " + customCssClass,
        });
        text.textContent = this.options.text;
        this.tags.push({
            element: text,
            parentId: "svg-" + this.options.id,
        });
    };
    /**
     * @description Draws a linear gradient into the foreground stroke
     */
    SimpleCircle.prototype.drawLinearGradient = function () {
        var attributes = {};
        attributes.gradientStart = this.options.strokeGradient[0];
        attributes.gradientEnd = this.options.strokeGradient[1];
        var defs = SvgTags.addDefs(attributes);
        this.tags.push({
            element: defs,
            parentId: "svg-" + this.options.id,
        });
    };
    return SimpleCircle;
}(BaseCircle));
export default SimpleCircle;
