import SvgTagsHelper from "./svg-tags-helper";
var StyleHelper = /** @class */ (function () {
    function StyleHelper() {
    }
    /**
     * @description Redraws the arc (circle) border
     * @param params
     * @param callback
     */
    StyleHelper.animateArc = function (params, callback) {
        var arc = params.arc, arcParams = params.arcParams, animationStep = params.animationStep, progressColors = params.progressColors;
        var startAngle = arcParams.startAngle ? arcParams.startAngle : 0;
        var endAngleGrade = arcParams.endAngleGrade ? arcParams.endAngleGrade : 360;
        var ms = this.getMilliseconds(arcParams.ms, arcParams.endAngleGrade);
        var hasProgressColor = Array.isArray(progressColors) && progressColors.length > 0;
        var count = 1;
        var interval = setInterval(function (arc, percent, progressColors) {
            var endAngle = endAngleGrade / 100 * count;
            SvgTagsHelper.setAttributes(arc, {
                d: SvgTagsHelper.describeArc(arcParams.x, arcParams.y, arcParams.radius, startAngle, endAngle),
            });
            if (hasProgressColor) {
                StyleHelper.updateCircleColor(count, arc, progressColors);
            }
            count += animationStep;
            if (count > percent) {
                clearInterval(interval);
                if (typeof callback === "function") {
                    callback();
                }
            }
        }, ms, arc, arcParams.percent, progressColors);
    };
    /**
     * @description If options.progressColors is set, colors are changed on given percentages
     * @param actualCount
     * @param arc
     * @param progressColors
     */
    StyleHelper.updateCircleColor = function (actualCount, arc, progressColors) {
        var progressColor = progressColors.find(function (progress) { return progress.percent === actualCount; });
        if (progressColor) {
            SvgTagsHelper.setAttributes(arc, {
                style: "stroke: " + progressColor.color,
            });
        }
    };
    /**
     * @param defaultMs
     * @param endAngleGrade
     */
    StyleHelper.getMilliseconds = function (defaultMs, endAngleGrade) {
        var ms = defaultMs ? defaultMs : 50;
        if (endAngleGrade <= 180) {
            ms = ms / 3;
        }
        return ms;
    };
    return StyleHelper;
}());
export { StyleHelper };
