var SvgTagsHelper = /** @class */ (function () {
    function SvgTagsHelper() {
    }
    /**
     * @description
     * @param element SVGElement
     * @param attributes IAvailableOptions
     * @returns void
     */
    SvgTagsHelper.setAttributes = function (element, attributes) {
        for (var _i = 0, _a = Object.entries(attributes); _i < _a.length; _i++) {
            var _b = _a[_i], key = _b[0], value = _b[1];
            element.setAttribute(key, value);
        }
    };
    /**
     * @description
     * @param element
     * @param attributes
     * @returns void
     */
    SvgTagsHelper.setAttributeNamespace = function (element, attributes) {
        for (var _i = 0, _a = Object.entries(attributes); _i < _a.length; _i++) {
            var _b = _a[_i], key = _b[0], value = _b[1];
            element.setAttributeNS(null, key, value);
        }
    };
    /**
     * @description For easier handling polar coordinates are used and converted to cartesian coordinates
     * @param centerX
     * @param centerY
     * @param radius
     * @param angleInDegrees
     * @returns object
     */
    SvgTagsHelper.polarToCartesian = function (centerX, centerY, radius, angleInDegrees) {
        var angleInRadians = (angleInDegrees - 90) * Math.PI / 180.0;
        return {
            x: centerX + radius * Math.cos(angleInRadians),
            y: centerY + radius * Math.sin(angleInRadians),
        };
    };
    /**
     * @description Returns the string for the data attribute in the path tag
     * @param x
     * @param y
     * @param radius
     * @param startAngle
     * @param endAngle
     * @returns string
     */
    SvgTagsHelper.describeArc = function (x, y, radius, startAngle, endAngle) {
        var start = SvgTagsHelper.polarToCartesian(x, y, radius, endAngle);
        var end = SvgTagsHelper.polarToCartesian(x, y, radius, startAngle);
        var largeArcFlag = endAngle - startAngle <= 180 ? "0" : "1";
        var closePath = false;
        if (endAngle === 360 && end.x > start.x) {
            closePath = true;
            start.x = start.x - 0.001;
        }
        return [
            "M", start.x, start.y,
            "A", radius, radius, 0, largeArcFlag, 0, end.x, end.y, (closePath ? "Z" : ""),
        ].join(" ");
    };
    /**
     * @description Returns the end coordinates of the arc
     * @param x
     * @param y
     * @param radius
     * @param endAngle
     */
    SvgTagsHelper.calculatePathEndCoordinates = function (x, y, radius, endAngle) {
        return SvgTagsHelper.polarToCartesian(x, y, radius, endAngle);
    };
    return SvgTagsHelper;
}());
export default SvgTagsHelper;
